package com.tianyi.interceptor;


import com.tianyi.mapper.SecretMapper;
import com.tianyi.sign.Signature;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@Slf4j
@Component
public class SignInterceptor implements HandlerInterceptor {

    private final SecretMapper secretMapper;

    public SignInterceptor(SecretMapper secretMapper) {
        this.secretMapper = secretMapper;
    }

    @SneakyThrows
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {

        response.setCharacterEncoding("UTF-8");
        response.setContentType("text/html;charset=UTF-8");
        //分配的应用id
        String appId = request.getHeader("appId");
        //时间戳
        String timestampStr = request.getHeader("timestamp");
        //签名
        String signature = request.getHeader("signature");
        if (StringUtils.isBlank(appId) || StringUtils.isBlank(timestampStr) || StringUtils.isBlank(signature)) {
            response.setStatus(500);
            response.getWriter().println("参数错误!");
            return false;
        }
        //这个密钥实际应该根据appId到数据库里查出来
        String appSecret = secretMapper.getAppSecret(appId);
        //如果密钥没查到
        if (StringUtils.isBlank(appSecret)) {
            response.setStatus(500);
            response.getWriter().println("密钥不存在,请联系平台进行授权!");
        }
        //拼接数据
        String origin = appId + appSecret + timestampStr;
        if (!Signature.verify(appSecret, origin, signature)) {
            response.setStatus(500);
            response.getWriter().println("签名错误!");
            return false;
        }
        //业务的时间戳
        long timestamp = Long.parseLong(timestampStr);
        //当前时间戳
        long currentTimestamp = System.currentTimeMillis() / 1000;
        //10分钟内有效
        long timeDifference = 10 * 60;
        if (Math.abs(timestamp - currentTimestamp) < timeDifference) {
            response.setStatus(500);
            response.getWriter().println("签名过期!");
            return false;
        }
        //放行
        return true;
    }


}
