package com.tianyi.service.impl;


import com.tianyi.model.RequestModel;
import com.tianyi.service.PdfToOfdService;
import lombok.SneakyThrows;
import org.apache.commons.lang3.StringUtils;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.rendering.PDFRenderer;
import org.ofdrw.graphics2d.OFDGraphicsDocument;
import org.ofdrw.graphics2d.OFDPageGraphics2D;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.net.URI;
import java.net.URL;
import java.net.URLConnection;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

@Service
public class PdfToOfdServiceImpl implements PdfToOfdService {

    private static final Logger log = LoggerFactory.getLogger(PdfToOfdServiceImpl.class);

    @Override
    @SneakyThrows
    public Object convert(RequestModel requestModel) {

        URL url = new URL(requestModel.getUrlStr());
        URLConnection urlConnection = url.openConnection();
        InputStream inputStream = urlConnection.getInputStream();
        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        try (OFDGraphicsDocument ofdDoc = new OFDGraphicsDocument(outputStream); PDDocument pdfDoc = PDDocument.load(inputStream)) {
            PDFRenderer pdfRender = new PDFRenderer(pdfDoc);
            for (int pageIndex = 0; pageIndex < pdfDoc.getNumberOfPages(); pageIndex++) {
                PDRectangle pdfPageSize = pdfDoc.getPage(pageIndex).getBBox();
                OFDPageGraphics2D ofdPageG2d = ofdDoc.newPage(pdfPageSize.getWidth(), pdfPageSize.getHeight());
                pdfRender.renderPageToGraphics(pageIndex, ofdPageG2d);
            }
        }
        Path out = null;
        String os=System.getProperty("os.name").toLowerCase();
        log.error("系统类别:{}",os);
        if (StringUtils.contains(os,"linux")){
            out=Paths.get("/home/ofd/ofddir/"+System.currentTimeMillis() + ".ofd");
        }
        if (StringUtils.contains(os,"windows")){
            out = Paths.get("target", System.currentTimeMillis() + ".ofd");
            Files.write(out, outputStream.toByteArray());
        }
        assert out != null;
        URI uri=out.toUri();
        return uri.getPath();
    }

}
